@@ -45,13 +45,13 @@ class Command(enum.IntEnum):
     EEPROM_EARSE = 0x24
     EEPROM_EARSE_ALL = 0x25
 
-    EXT_FLASH_SET_PGSZ = 0x30
-    EXT_FLASH_GET_PGSZ = 0x31
+    EXT_FLASH_FOPEN = 0x30
+    EXT_FLASH_FCLOSE = 0x31
     EXT_FLASH_WRITE = 0x32
     EXT_FLASH_READ = 0x33
     EXT_FLASH_VARIFY = 0x34
     EXT_FLASH_EARSE_SECTOR = 0x35
-    EXT_FLASH_EARSE_ALL = 0x36
+    EXT_FLASH_HEX_DEL = 0x36
 
 class Decoder(object):
     class _Status(enum.IntEnum):
