@@ -267,8 +267,7 @@ class CommandTrnasHandler():
         rep = self._get_packet()
         if rep['command'] == alp.Command.EXT_FLASH_FOPEN and rep['data'][0] == 0:
             self.cmd_ext_flash_hex_delete()
-            self.cmd_ext_flash_prepare(filename)
-            return True
+            return self.cmd_ext_flash_prepare(filename)
         elif rep['command'] == alp.Command.EXT_FLASH_FOPEN and rep['data'][0] == 2:
             return True
         else:
